@@ -297,7 +297,7 @@ class JSON2EDCLineageFiles:
                 if entity_attribute["uid"] == attribute:
                     print("Found: entity_attribute >%s< is named >%s<" % (entity_attribute["uid"], entity_attribute["name"]))
                     return True, entity, entity_attribute["name"]
-        print("NOT FOUND: attribute >%s< in entity list >%s<", attribute, str(entities))
+        print("NOT FOUND: attribute >%s< in entity list >%s<" % (attribute, str(entities)))
         return False, None, None
 
     def get_attributes(self, entity):
